summaryrefslogtreecommitdiff
path: root/apf_run_test.sh
diff options
context:
space:
mode:
Diffstat (limited to 'apf_run_test.sh')
-rwxr-xr-xapf_run_test.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/apf_run_test.sh b/apf_run_test.sh
index b365e84..12bbfe0 100755
--- a/apf_run_test.sh
+++ b/apf_run_test.sh
@@ -8,7 +8,7 @@ testname=$(basename $(basename $0 .sh))
retcode=0
# Loop through testcases and run each one.
# Each testcase is composed of a program, a packet, optionally the starting data, and the output.
for prog in testdata/*.program; do
testcase=$(basename $prog .program)
prog=$(cat testdata/$testcase.program)
@@ -19,6 +19,9 @@ for prog in testdata/*.program; do
if [[ -f testdata/$testcase.data ]]; then
args="$args --data $(cat testdata/$testcase.data)"
fi
+ if [[ -f testdata/$testcase.age ]]; then
+ args="$args --age $(cat testdata/$testcase.age)"
+ fi
if diff --color -u <(apf_run $args) <(cat $outputpath); then
echo $testname: $testcase: PASS
@@ -8,7 +8,7 @@ testname=$(basename $(basename $0 .sh))
retcode=0
# Loop through testcases and run each one.
-# Each testcase is composed of a program, a packet, optionally the starting data, and the output.
+# Each testcase is composed of program, packet, output, and optionally, starting data and/or age.
for prog in testdata/*.program; do
testcase=$(basename $prog .program)